==> haskell-network-simple-0.4.5-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-HnVmQn244No510mtvN0GvX
key:                  network-simple-0.4.5-HnVmQn244No510mtvN0GvX
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  6bea2a522af79e4edcc780639f4ec614
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-HnVmQn244No510mtvN0GvX
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    network-3.1.4.0-IMH4i2bhORraAL0d8HxBg
    network-bsd-2.8.1.0-Hi9BTJ8xkn681MwAh6rNkU
    safe-exceptions-0.1.7.4-BFjUnV2nLAB1SsdHVx5ZMJ
    socks-0.6.1-9n9Rda5G5qi62IT7yrYDA3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-simple-0.4.5-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-LqlxUpvmC0j9igBCaGUoV3
key:                  network-simple-0.4.5-LqlxUpvmC0j9igBCaGUoV3
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  eac15bce2fd47befc0e3e3057e2a686f
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-LqlxUpvmC0j9igBCaGUoV3
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy
    network-bsd-2.8.1.0-TpYpSMVO2fI0iOwqbogrF
    safe-exceptions-0.1.7.4-GPoXaqbHmse2qLBXsbf3lC
    socks-0.6.1-3imUcjBJkbv99nx4DmSGqS transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
